package org.framework.lazy.cloud.network.heartbeat.protocol.handler;

import io.netty.bootstrap.Bootstrap;
import io.netty.channel.Channel;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.SimpleChannelInboundHandler;
import io.netty.channel.socket.DatagramPacket;
import io.netty.channel.socket.nio.NioDatagramChannel;
import lombok.extern.slf4j.Slf4j;
import org.framework.lazy.cloud.network.heartbeat.common.adapter.ChannelTypeAdapter;

import java.net.InetSocketAddress;

/**
 * description 服务端数据处理器
 *
 * @author 吴佳伟
 * @date 2023/09/13 10:27
 */
@Slf4j
public class NettyUdpProxyHandler extends SimpleChannelInboundHandler<DatagramPacket> {

    private final ChannelTypeAdapter channelTypeAdapter;
    private InetSocketAddress targetAddress = new InetSocketAddress("example.com", 80);

    public NettyUdpProxyHandler(ChannelTypeAdapter channelTypeAdapter) {
        this.channelTypeAdapter = channelTypeAdapter;
    }

    @Override
    protected void channelRead0(ChannelHandlerContext ctx, DatagramPacket packet) throws Exception {
        Bootstrap b = new Bootstrap();
        b.group(ctx.channel().eventLoop())
                .channel(NioDatagramChannel.class)
                .handler(new NettyUdpProxyBackendHandler(ctx.channel(), packet.sender()));

        Channel channel = b.bind(0).sync().channel();
        channel.writeAndFlush(new DatagramPacket(packet.content().retain(), targetAddress));
    }

    @Override
    public void exceptionCaught(ChannelHandlerContext ctx, Throwable cause) throws Exception {
        cause.printStackTrace();
        ctx.close();
    }
}