package org.framework.lazy.cloud.network.heartbeat.server.netty.proxy.http.advanced;


import io.netty.channel.Channel;
import lombok.extern.slf4j.Slf4j;
import org.framework.lazy.cloud.network.heartbeat.common.ChannelContext;
import org.framework.lazy.cloud.network.heartbeat.common.NettyByteBuf;
import org.framework.lazy.cloud.network.heartbeat.common.NettyProxyMsg;
import org.framework.lazy.cloud.network.heartbeat.common.NettyTransferChannelContext;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.server.AbstractHandleHttpReportClientProxyClientConnectionTransferTypeAdvanced;
import org.framework.lazy.cloud.network.heartbeat.common.constant.TcpMessageType;
import org.framework.lazy.cloud.network.heartbeat.common.utils.ChannelAttributeKeyUtils;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.Role;
import org.springframework.stereotype.Component;


/**
 * 服务端处理客户端代理到服务端的请求
 * HTTP_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_REPORT_
 */
@Role(BeanDefinition.ROLE_INFRASTRUCTURE)
@Slf4j
@Component
public class ServerHandleHttpReportClientProxyClientConnectTransferTypeAdvanced
        extends AbstractHandleHttpReportClientProxyClientConnectionTransferTypeAdvanced<NettyProxyMsg> {


    /**
     * 处理当前数据
     *
     * @param transferChannel 当前通道
     * @param nettyProxyMsg        通道数据
     */
    @Override
    public void doHandler(Channel transferChannel, NettyProxyMsg nettyProxyMsg) {
        // 创建链接、发送数据
        String targetPortString = nettyProxyMsg.getTargetPortString();
        String targetIpString = nettyProxyMsg.getTargetIpString();
        byte[] data = nettyProxyMsg.getData();
        byte[] visitorId = nettyProxyMsg.getVisitorId();
        byte[] clientId = nettyProxyMsg.getClientId();
        String msgVisitorId = new String(visitorId);
        ChannelAttributeKeyUtils.buildClientId(transferChannel, clientId);
        ChannelAttributeKeyUtils.buildVisitorId(transferChannel, msgVisitorId);

        NettyTransferChannelContext.pushVisitor(transferChannel, msgVisitorId);
        NettyByteBuf nettyByteBuf = new NettyByteBuf();
        nettyByteBuf.setData(data);
        ChannelAttributeKeyUtils.buildNettyByteBufData(transferChannel, nettyByteBuf);
        // 获取客户端心跳通道
        Channel loadBalance = ChannelContext.getLoadBalance(clientId);

        NettyProxyMsg clientConnectTagetNettyProxyMsg = new NettyProxyMsg();
        clientConnectTagetNettyProxyMsg.setVisitorId(msgVisitorId);
        clientConnectTagetNettyProxyMsg.setClientTargetIp(targetIpString);
        clientConnectTagetNettyProxyMsg.setClientTargetPort(Integer.parseInt(targetPortString));
        clientConnectTagetNettyProxyMsg.setClientId(clientId);
        clientConnectTagetNettyProxyMsg.setType(TcpMessageType.HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_SUCCESSFUL_);
        if (loadBalance != null) {
            // 让客户端主动创建一个数据传输通道
            loadBalance.writeAndFlush(clientConnectTagetNettyProxyMsg);
        }else {
            log.error("can not find target client:【】 channel",clientId);
        }

    }

}
