package org.framework.lazy.cloud.network.heartbeat.server.standalone.application;

import org.wu.framework.web.response.Result;
import org.wu.framework.web.response.ResultFactory;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.domain.model.lazy.netty.client.route.LazyNettyClientRoute;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.client.route.LazyNettyClientRouteRemoveCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.client.route.LazyNettyClientRouteStoryCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.client.route.LazyNettyClientRouteUpdateCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.client.route.LazyNettyClientRouteQueryListCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.client.route.LazyNettyClientRouteQueryOneCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.dto.LazyNettyClientRouteDTO;
import java.util.List;
import org.wu.framework.lazy.orm.database.lambda.domain.LazyPage;
/**
 * describe 客户端代理路由规则 
 *
 * @author Jia wei Wu
 * @date 2025/04/05 09:00 晚上
 * @see org.wu.framework.lazy.orm.core.persistence.reverse.lazy.ddd.DefaultDDDLazyApplication 
 **/

public interface LazyNettyClientRouteApplication {


    /**
     * describe 新增客户端代理路由规则
     *
     * @param lazyNettyClientRouteStoryCommand 新增客户端代理路由规则     
     * @return {@link Result<LazyNettyClientRoute>} 客户端代理路由规则新增后领域对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyClientRoute> story(LazyNettyClientRouteStoryCommand lazyNettyClientRouteStoryCommand);

    /**
     * describe 批量新增客户端代理路由规则
     *
     * @param lazyNettyClientRouteStoryCommandList 批量新增客户端代理路由规则     
     * @return {@link Result<List<LazyNettyClientRoute>>} 客户端代理路由规则新增后领域对象集合     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<List<LazyNettyClientRoute>> batchStory(List<LazyNettyClientRouteStoryCommand> lazyNettyClientRouteStoryCommandList);

    /**
     * describe 更新客户端代理路由规则
     *
     * @param lazyNettyClientRouteUpdateCommand 更新客户端代理路由规则     
     * @return {@link Result<LazyNettyClientRoute>} 客户端代理路由规则领域对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyClientRoute> updateOne(LazyNettyClientRouteUpdateCommand lazyNettyClientRouteUpdateCommand);

    /**
     * describe 查询单个客户端代理路由规则
     *
     * @param lazyNettyClientRouteQueryOneCommand 查询单个客户端代理路由规则     
     * @return {@link Result<LazyNettyClientRouteDTO>} 客户端代理路由规则DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyClientRouteDTO> findOne(LazyNettyClientRouteQueryOneCommand lazyNettyClientRouteQueryOneCommand);

    /**
     * describe 查询多个客户端代理路由规则
     *
     * @param lazyNettyClientRouteQueryListCommand 查询多个客户端代理路由规则     
     * @return {@link Result <List<LazyNettyClientRouteDTO>>} 客户端代理路由规则DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result <List<LazyNettyClientRouteDTO>> findList(LazyNettyClientRouteQueryListCommand lazyNettyClientRouteQueryListCommand);

    /**
     * describe 分页查询多个客户端代理路由规则
     *
     * @param lazyNettyClientRouteQueryListCommand 分页查询多个客户端代理路由规则     
     * @return {@link Result <LazyPage<LazyNettyClientRouteDTO>>} 分页客户端代理路由规则DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result <LazyPage<LazyNettyClientRouteDTO>> findPage(int size,int current,LazyNettyClientRouteQueryListCommand lazyNettyClientRouteQueryListCommand);

    /**
     * describe 删除客户端代理路由规则
     *
     * @param lazyNettyClientRouteRemoveCommand 删除客户端代理路由规则     
     * @return {@link Result<LazyNettyClientRoute>} 客户端代理路由规则     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyClientRoute> remove(LazyNettyClientRouteRemoveCommand lazyNettyClientRouteRemoveCommand);

}