package org.framework.lazy.cloud.network.heartbeat.server.standalone.application;

import org.wu.framework.web.response.Result;
import org.wu.framework.web.response.ResultFactory;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.domain.model.lazy.netty.server.route.LazyNettyServerRoute;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.route.LazyNettyServerRouteRemoveCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.route.LazyNettyServerRouteStoryCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.route.LazyNettyServerRouteUpdateCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.route.LazyNettyServerRouteQueryListCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.route.LazyNettyServerRouteQueryOneCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.dto.LazyNettyServerRouteDTO;
import java.util.List;
import org.wu.framework.lazy.orm.database.lambda.domain.LazyPage;
/**
 * describe 服务端路由 
 *
 * @author Jia wei Wu
 * @date 2025/04/05 09:00 晚上
 * @see org.wu.framework.lazy.orm.core.persistence.reverse.lazy.ddd.DefaultDDDLazyApplication 
 **/

public interface LazyNettyServerRouteApplication {


    /**
     * describe 新增服务端路由
     *
     * @param lazyNettyServerRouteStoryCommand 新增服务端路由     
     * @return {@link Result<LazyNettyServerRoute>} 服务端路由新增后领域对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyServerRoute> story(LazyNettyServerRouteStoryCommand lazyNettyServerRouteStoryCommand);

    /**
     * describe 批量新增服务端路由
     *
     * @param lazyNettyServerRouteStoryCommandList 批量新增服务端路由     
     * @return {@link Result<List<LazyNettyServerRoute>>} 服务端路由新增后领域对象集合     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<List<LazyNettyServerRoute>> batchStory(List<LazyNettyServerRouteStoryCommand> lazyNettyServerRouteStoryCommandList);

    /**
     * describe 更新服务端路由
     *
     * @param lazyNettyServerRouteUpdateCommand 更新服务端路由     
     * @return {@link Result<LazyNettyServerRoute>} 服务端路由领域对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyServerRoute> updateOne(LazyNettyServerRouteUpdateCommand lazyNettyServerRouteUpdateCommand);

    /**
     * describe 查询单个服务端路由
     *
     * @param lazyNettyServerRouteQueryOneCommand 查询单个服务端路由     
     * @return {@link Result<LazyNettyServerRouteDTO>} 服务端路由DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyServerRouteDTO> findOne(LazyNettyServerRouteQueryOneCommand lazyNettyServerRouteQueryOneCommand);

    /**
     * describe 查询多个服务端路由
     *
     * @param lazyNettyServerRouteQueryListCommand 查询多个服务端路由     
     * @return {@link Result <List<LazyNettyServerRouteDTO>>} 服务端路由DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result <List<LazyNettyServerRouteDTO>> findList(LazyNettyServerRouteQueryListCommand lazyNettyServerRouteQueryListCommand);

    /**
     * describe 分页查询多个服务端路由
     *
     * @param lazyNettyServerRouteQueryListCommand 分页查询多个服务端路由     
     * @return {@link Result <LazyPage<LazyNettyServerRouteDTO>>} 分页服务端路由DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result <LazyPage<LazyNettyServerRouteDTO>> findPage(int size,int current,LazyNettyServerRouteQueryListCommand lazyNettyServerRouteQueryListCommand);

    /**
     * describe 删除服务端路由
     *
     * @param lazyNettyServerRouteRemoveCommand 删除服务端路由     
     * @return {@link Result<LazyNettyServerRoute>} 服务端路由     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyServerRoute> remove(LazyNettyServerRouteRemoveCommand lazyNettyServerRouteRemoveCommand);

}