package org.framework.lazy.cloud.network.heartbeat.server.standalone.domain.model.lazy.netty.server.route;

import org.wu.framework.web.response.Result;
import org.wu.framework.web.response.ResultFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.domain.model.lazy.netty.server.route.LazyNettyServerRoute;
import java.util.List;
import org.wu.framework.lazy.orm.database.lambda.domain.LazyPage;
/**
 * describe 服务端路由 
 *
 * @author Jia wei Wu
 * @date 2025/04/05 09:00 晚上
 * @see org.wu.framework.lazy.orm.core.persistence.reverse.lazy.ddd.DefaultDDDLazyDomainRepository 
 **/

public interface LazyNettyServerRouteRepository {


    /**
     * describe 新增服务端路由
     *
     * @param lazyNettyServerRoute 新增服务端路由     
     * @return {@link  Result<LazyNettyServerRoute>} 服务端路由新增后领域对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyServerRoute> story(LazyNettyServerRoute lazyNettyServerRoute);

    /**
     * describe 批量新增服务端路由
     *
     * @param lazyNettyServerRouteList 批量新增服务端路由     
     * @return {@link Result<List<LazyNettyServerRoute>>} 服务端路由新增后领域对象集合     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<List<LazyNettyServerRoute>> batchStory(List<LazyNettyServerRoute> lazyNettyServerRouteList);

    /**
     * describe 查询单个服务端路由
     *
     * @param lazyNettyServerRoute 查询单个服务端路由     
     * @return {@link Result<LazyNettyServerRoute>} 服务端路由DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyServerRoute> findOne(LazyNettyServerRoute lazyNettyServerRoute);

    /**
     * describe 查询多个服务端路由
     *
     * @param lazyNettyServerRoute 查询多个服务端路由     
     * @return {@link Result<List<LazyNettyServerRoute>>} 服务端路由DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<List<LazyNettyServerRoute>> findList(LazyNettyServerRoute lazyNettyServerRoute);

    /**
     * describe 分页查询多个服务端路由
     *
     * @param size 当前页数
     * @param current 当前页
     * @param lazyNettyServerRoute 分页查询多个服务端路由     
     * @return {@link Result<LazyPage<LazyNettyServerRoute>>} 分页服务端路由领域对象     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyPage<LazyNettyServerRoute>> findPage(int size,int current,LazyNettyServerRoute lazyNettyServerRoute);

    /**
     * describe 删除服务端路由
     *
     * @param lazyNettyServerRoute 删除服务端路由     
     * @return {@link Result<LazyNettyServerRoute>} 服务端路由     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<LazyNettyServerRoute> remove(LazyNettyServerRoute lazyNettyServerRoute);

    /**
     * describe 是否存在服务端路由
     *
     * @param lazyNettyServerRoute 是否存在服务端路由     
     * @return {@link Result<Boolean>} 服务端路由是否存在     
     
     * @author Jia wei Wu
     * @date 2025/04/05 09:00 晚上
     **/

    Result<Boolean> exists(LazyNettyServerRoute lazyNettyServerRoute);

}